ImportDescriptorsRequest

Struct ImportDescriptorsRequest 

pub struct ImportDescriptorsRequest {
    pub desc: String,
    pub active: Option<bool>,
    pub range: Option<(usize, usize)>,
    pub next_index: Option<usize>,
    pub timestamp: u64,
    pub internal: Option<bool>,
    pub label: Option<String>,
}
Request of importdescriptors.

Fields

desc: String

(required) Descriptor to import.

active: Option<bool>

Set this descriptor to be the active descriptor for the corresponding output type.

range: Option<(usize, usize)>

If a ranged descriptor is used, this specifies the range (in the form [begin,end]) to import.

next_index: Option<usize>

The next index from which to generate addresses.

timestamp: u64

(required) Time from which to start rescanning the blockchain for this descriptor, in UNIX epoch time.

internal: Option<bool>

Whether matching outputs should be treated as not incoming payments (e.g. change).

label: Option<String>

Label to assign to the address, only allowed with internal = false. Disabled for ranged descriptors.